@@ -26,18 +26,13 @@ class Exchange(StrEnum):
 
     BINANCE = "BINANCE"
     BITGET = "BITGET"
-    BITRUE = "BITRUE"
     BITUNIX = "BITUNIX"
-    BTSE = "BTSE"
     BYBIT = "BYBIT"
-    GATEIO = "GATEIO"
+    GATE = "GATE"
     HYPERLIQUID = "HYPERLIQUID"
     KCEX = "KCEX"
-    KRAKEN = "KRAKEN"
-    KUCOIN = "KUCOIN"
     MEXC = "MEXC"
     OKX = "OKX"
-    WEEX = "WEEX"
     XT = "XT"
 
     def __add__(self, market_type: "MarketType") -> tuple["Exchange", "MarketType"]:
@@ -199,7 +194,7 @@ class Timeframe(StrEnum):
                 Timeframe.WEEK_1: "1W",
                 Timeframe.MONTH_1: "1M",
             },
-            (Exchange.GATEIO, MarketType.FUTURES): {
+            (Exchange.GATE, MarketType.FUTURES): {
                 Timeframe.SECOND_1: "1s",
                 Timeframe.MIN_1: "1m",
                 Timeframe.MIN_5: "5m",
@@ -215,7 +210,7 @@ class Timeframe(StrEnum):
                 Timeframe.WEEK_1: "1w",
                 Timeframe.MONTH_1: "30d",
             },
-            (Exchange.GATEIO, MarketType.SPOT): {
+            (Exchange.GATE, MarketType.SPOT): {
                 Timeframe.MIN_1: "1m",
                 Timeframe.MIN_5: "5m",
                 Timeframe.MIN_15: "15m",
@@ -227,6 +222,22 @@ class Timeframe(StrEnum):
                 Timeframe.WEEK_1: "7d",
                 Timeframe.MONTH_1: "30d",
             },
+            Exchange.HYPERLIQUID: {
+                Timeframe.MIN_1: "1m",
+                Timeframe.MIN_3: "3m",
+                Timeframe.MIN_5: "5m",
+                Timeframe.MIN_15: "15m",
+                Timeframe.MIN_30: "30m",
+                Timeframe.HOUR_1: "1h",
+                Timeframe.HOUR_2: "2h",
+                Timeframe.HOUR_4: "4h",
+                Timeframe.HOUR_8: "8h",
+                Timeframe.HOUR_12: "12h",
+                Timeframe.DAY_1: "1d",
+                Timeframe.DAY_3: "3d",
+                Timeframe.WEEK_1: "1w",
+                Timeframe.MONTH_1: "1M",
+            },
         }
 
     def to_exchange_format(self, exchange: Exchange, market_type: MarketType | None = None) -> str:
