@@ -11,6 +11,9 @@ __all__ = [
     "AccountType",
     "OpenInterestDict",
     "OpenInterestItem",
+    "TickerInfoItem",
+    "TickersInfoDict",
+    "LiquidationDict",
 ]
 
 from logging import Logger as LoggingLogger
@@ -115,5 +118,52 @@ type OpenInterestDict = dict[str, OpenInterestItem]
 """Модель открытого интереса."""
 
 
+class LiquidationDict(TypedDict):
+    """Модель ликвидации."""
+
+    t: int
+    """Время. В миллисекундах."""
+
+    s: str
+    """Символ."""
+
+    S: Literal["BUY", "SELL"]
+    """Сторона."""
+
+    v: float
+    """Объем ликвидации. В монетах."""
+
+    p: float
+    """Цена ликвидации."""
+
+
 type AccountType = Literal["SPOT", "FUTURES"]
 """Тип аккаунта."""
+
+
+class TickerInfoItem(TypedDict):
+    """Информация о размерах тиков, ступеней цены и множителя контракта (если есть) для тикера.
+
+    На некоторых биржах удобнее делать округление через precisions, на некоторых через step,
+    потому что иногда встречаются шаги, которые не являются степенью 10. Поэтому обязательно
+    должны быть определены tick_precision ИЛИ tick_step, а так же size_precision ИЛИ size_step.
+    """
+
+    tick_precision: int | None
+    """Количество знаков после запятой для цены."""
+
+    tick_step: float | None
+    """Шаг одного деления для цены."""
+
+    size_precision: int | None
+    """Количество знаков после запятой для объема."""
+
+    size_step: float | None
+    """Шаг одного деления для объема."""
+
+    contract_size: float | None
+    """Множитель контракта (если есть)."""
+
+
+type TickersInfoDict = dict[str, TickerInfoItem]
+"""Информация о размерах тиков, ступеней цены и множителя контракта (если есть) для всех тикеров."""
